@@ -24,11 +24,11 @@ class faker():
             return date
 
 if __name__ == '__main__':
-    host = ''
-    port = ''
-    user = ''
-    password = ''
-    database = ''
-    key1 = ''
+    host = '192.168.84.26'
+    port = '30006'
+    user = 'root'
+    password = 'eisoo.com'
+    database = 'AnyRobot'
+    key1 = 'tagID'
     date1 = faker(host,port,user,password,database).route(key1)
     print(date1)
\ No newline at end of file
