@@ -67,18 +67,17 @@ def filed(key,inquire=[]):
         'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId,
         'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
         'UtcStartID': ParaDateFiledServer().getUtcStartTime,
-        'UtcEndID': ParaDateFiledServer().getUtcEndTime,
-        'LogwareHouse': ParaDateAnyRobotServer(key).getLogwareHouse,
-        'dataType': ParaDateAnyRobotServer(key).getdataType,
-        'indexID': ParaDateAnyRobotServer(key).getindexID,
-        'indexName': ParaDateAnyRobotServer(key).getindexName,
-        'StreamId': ParaDateAnyRobotServer(key).getStreamId,
-        'LogGroupIdPare': ParaDateAnyRobotServer(key).getLogGroupIdPare,
-        'UserID': ParaDateAnyRobotServer(key).getUserID,
-        'RoleId': ParaDateAnyRobotServer(key).getRoleId,
-        'tagGroupID': ParaDateAnyRobotServer(key).gettagGroupID,
-        'tagID': ParaDateAnyRobotServer(key).gettagID,
-        'HostID': ParaDateAnyRobotServer(key).getIp
+        'UtcEndID': ParaDateFiledServer().getUtcEndTime
+        # 'LogwareHouse': ParaDateAnyRobotServer(key).getLogwareHouse,
+        # 'dataType': ParaDateAnyRobotServer(key).getdataType,
+        # 'indexID': ParaDateAnyRobotServer(key).getindexID,
+        # 'indexName': ParaDateAnyRobotServer(key).getindexName,
+        # 'StreamId': ParaDateAnyRobotServer(key).getStreamId,
+        # 'LogGroupIdPare': ParaDateAnyRobotServer(key).getLogGroupIdPare,
+        # 'UserID': ParaDateAnyRobotServer(key).getUserID,
+        # 'RoleId': ParaDateAnyRobotServer(key).getRoleId,
+        # 'tagGroupID': ParaDateAnyRobotServer(key).gettagGroupID,
+        # 'tagID': ParaDateAnyRobotServer(key).gettagID,
     }
 
     switcher = SERVICE_KPI_
